import fs from "fs/promises"
import path from "path"
import { chapters } from "@/data/chapters"

export async function checkLessonFiles() {
  const result: Record<string, any> = {}

  for (const chapter of chapters) {
    const chapterId = chapter.chapter.split(". ")[1].toLowerCase().replace(/ /g, "-")
    const chapterDir = path.join(process.cwd(), "data", "lessons", chapterId)

    result[chapterId] = {
      title: chapter.chapter,
      lessons: [],
    }

    try {
      // Vérifier si le dossier existe
      await fs.access(chapterDir)

      // Lister les fichiers dans le dossier
      const files = await fs.readdir(chapterDir)

      // Pour chaque leçon dans le chapitre
      for (const lesson of chapter.lessons) {
        const lessonId = lesson.title.toLowerCase().replace(/ /g, "-")
        const expectedFilename = `${lessonId}.html`

        result[chapterId].lessons.push({
          title: lesson.title,
          id: lessonId,
          expectedFilename,
          exists: files.includes(expectedFilename),
          availableFiles: files,
        })
      }
    } catch (error) {
      result[chapterId].error = (error as Error).message
    }
  }

  return result
}
